/*
 * This file contains the list of permission scopes supported by extensions and various helper
 * functions for using scopes.
 *
 * For more info, see: https://github.com/netlify/jigsaw/blob/main/scopes/scopes.go
 *
 * TODO(ndhoule): Generate the ExtensionScope automatically from an OpenAPI schema, from Go source,
 * etc.
 */
/**
 * An enum containing all extension permission scopes. These scopes are primarily used to restrict
 * interactions with the Netlify API (Bitballoon).
 *
 * @internal
 */
export var ExtensionScope;
(function (ExtensionScope) {
    /**
     * @deprecated This scope only exists for v1 extension support. It's used by v2 extensions in the
     * enable flow, but the permissions it grants are not required to enable a v2 extension.
     */
    ExtensionScope["EnableExtension"] = "enable";
    ExtensionScope["EnvRead"] = "env:read";
    ExtensionScope["EnvWrite"] = "env:write";
    ExtensionScope["EnvDelete"] = "env:delete";
    ExtensionScope["SiteRead"] = "site:read";
    ExtensionScope["SiteWrite"] = "site:write";
    ExtensionScope["UserRead"] = "user:read";
    ExtensionScope["UserWrite"] = "user:write";
})(ExtensionScope || (ExtensionScope = {}));
/**
 * humanizeExtensionScope returns an object containing human-readable labels for that scope.
 *
 * @internal
 */
export const humanizeExtensionScope = (scope) => {
    switch (scope) {
        case ExtensionScope.EnableExtension:
            return { resource: "Extension", action: "Enable" };
        case ExtensionScope.EnvRead:
            return { resource: "Environment variables", action: "Read" };
        case ExtensionScope.EnvWrite:
            return { resource: "Environment variables", action: "Write" };
        case ExtensionScope.EnvDelete:
            return { resource: "Environment variables", action: "Delete" };
        case ExtensionScope.SiteRead:
            return { resource: "Site", action: "Read" };
        case ExtensionScope.SiteWrite:
            return { resource: "Site", action: "Write" };
        case ExtensionScope.UserRead:
            return { resource: "User", action: "Read" };
        case ExtensionScope.UserWrite:
            return { resource: "User", action: "Write" };
    }
};
/**
 * deserializeExtensionScopes transforms a serialized list of scopes into an array of
 * ExtensionScopes. Throws if the list is malformed or contains invalid scopes.
 *
 * @internal
 */
export const deserializeExtensionScopes = (value) => {
    const parts = value.split(",").map((part) => part.trim());
    const invalidScopes = parts.filter((part) => !isValidExtensionScope(part));
    if (invalidScopes.length) {
        throw new Error(`Invalid scope(s): ${invalidScopes.map((invalidScope) => `"${invalidScope}"`).join(", ")}`);
    }
    return parts.filter((part) => isValidExtensionScope(part));
};
/**
 * serializeExtensionScopes serializes a list of extension scopes into a format suitable for
 * consumption by the Jigsaw API.
 *
 * @internal
 */
export const serializeExtensionScopes = (scopes) => scopes.join(",");
const extensionScopes = new Set(Object.values(ExtensionScope));
/**
 * isValidExtensionScope checks if a given value is a valid ExtensionScope.
 *
 * @internal
 */
export const isValidExtensionScope = (value) => typeof value === "string" && extensionScopes.has(value);
//# sourceMappingURL=scopes.js.map